@@ -16,6 +16,7 @@
 # limitations under the License.
 
 from oslo_config import cfg
+from oslo_log import log as logging
 import pyroute2
 
 from networking_bagpipe.bagpipe_bgp.common import log_decorator
@@ -23,7 +24,7 @@ from networking_bagpipe.bagpipe_bgp import constants as consts
 from networking_bagpipe.bagpipe_bgp.engine import exa
 from networking_bagpipe.bagpipe_bgp.vpn import dataplane_drivers as dp_drivers
 from networking_bagpipe.bagpipe_bgp.vpn import evpn
-
+from networking_bagpipe.privileged import privileged_utils
 
 BRIDGE_NAME_PREFIX = "evpn---"
 VXLAN_INTERFACE_PREFIX = "vxlan--"
@@ -41,8 +42,6 @@ class LinuxVXLANEVIDataplane(evpn.VPNInstanceDataplane):
                 BRIDGE_NAME_PREFIX +
                 self.external_instance_id)[:consts.LINUX_DEV_LEN]
 
-        self.log.info("EVI %d: Initializing bridge %s",
-                      self.instance_id, self.bridge_name)
         if not self._interface_exists(self.bridge_name):
             self.log.debug("Starting bridge %s", self.bridge_name)
 
@@ -160,10 +159,13 @@ class LinuxVXLANEVIDataplane(evpn.VPNInstanceDataplane):
 
     def _is_if_on_bridge(self, ifname):
         with pyroute2.IPDB(plugins=('interfaces',)) as ipdb:
-            for port_id in ipdb.interfaces[self.bridge_name].ports:
-                port = ipdb.interfaces[port_id]
-                if port.ifname == ifname:
-                    return True
+            try:
+                for port_id in ipdb.interfaces[self.bridge_name].ports:
+                    port = ipdb.interfaces[port_id]
+                    if port.ifname == ifname:
+                        return True
+            except KeyError:
+                return False
         return False
 
     def _is_vxlan_if_on_bridge(self):
@@ -324,9 +326,10 @@ class LinuxVXLANEVIDataplane(evpn.VPNInstanceDataplane):
         self._fdb_dump()
 
     def _fdb_dump(self):
-        if self.log.debug:
+        if self.log.isEnabledFor(logging.DEBUG):
             self.log.debug("bridge fdb dump: %s", self._run_command(
                 "bridge fdb show br %s" % self.bridge_name,
+                acceptable_return_codes=[0, 255],
                 run_as_root=True)[0])
 
     # Looking glass ####
@@ -356,7 +359,7 @@ class LinuxVXLANDataplaneDriver(dp_drivers.DataplaneDriver):
     def __init__(self):
         super(LinuxVXLANDataplaneDriver, self).__init__()
 
-        self._run_command("modprobe vxlan", run_as_root=True)
+        privileged_utils.modprobe('vxlan')
 
     @log_decorator.log_info
     def reset_state(self):
