@@ -29,6 +29,7 @@ from networking_bagpipe.bagpipe_bgp.common import looking_glass as lg
 from networking_bagpipe.bagpipe_bgp import constants as consts
 from networking_bagpipe.bagpipe_bgp.engine import exa
 from networking_bagpipe.bagpipe_bgp.vpn import dataplane_drivers as dp_drivers
+from networking_bagpipe.privileged import privileged_utils
 
 
 ipr = pyroute2.IPRoute()  # pylint: disable=no-member
@@ -48,14 +49,7 @@ def json_set_default(obj):
 
 
 def sysctl(sysctl_path, val):
-    if isinstance(sysctl_path, (tuple, list)):
-        filename = ('/'.join(sysctl_path))
-    else:
-        filename = sysctl_path.replace('.', '/')
-    filename = '/proc/sys/' + filename
-
-    with open(filename, 'w') as f:
-        f.write(str(val))
+    privileged_utils.sysctl(knob='.'.join(sysctl_path,), value=val)
 
 
 def proxy_arp(ifname, enable):
@@ -76,8 +70,7 @@ class MPLSLinuxVRFDataplane(dp_drivers.VPNInstanceDataplane):
 
         self.rt_table = RT_TABLE_BASE + self.instance_id
 
-        self.log.info("VRF %d: Initializing VRF interface %s",
-                      self.instance_id, self.vrf_if)
+        self.log.info("Initializing VRF interface %s", self.vrf_if)
 
         self.flush_routes()
 
@@ -171,12 +164,12 @@ class MPLSLinuxVRFDataplane(dp_drivers.VPNInstanceDataplane):
         # FIXME: that would need to be per vif port
         # Retrieve broadcast IP address
         broadcast_ip = str(netaddr.IPNetwork("%s/%s" % (self.gateway_ip,
-                                                        self.mask)
+                                                        self.network_plen)
                                              ).broadcast)
 
         try:
             ipr.addr('add', index=self.ip.interfaces[interface].index,
-                     address=self.gateway_ip, mask=self.mask,
+                     address=self.gateway_ip, mask=self.network_plen,
                      broadcast=broadcast_ip)
         except netlink.exceptions.NetlinkError as x:
             if x.code == errno.EEXIST:
@@ -230,11 +223,11 @@ class MPLSLinuxVRFDataplane(dp_drivers.VPNInstanceDataplane):
         # Unconfigure gateway address on this port
         # FIXME: that would need to be per vif port
         # Retrieve broadcast IP address
-        ip = netaddr.IPNetwork("%s/%s" % (self.gateway_ip, self.mask))
+        ip = netaddr.IPNetwork("%s/%s" % (self.gateway_ip, self.network_plen))
         broadcast_ip = str(ip.broadcast)
 
         ipr.addr('del', index=self.ip.interfaces[interface].index,
-                 address=self.gateway_ip, mask=self.mask,
+                 address=self.gateway_ip, mask=self.network_plen,
                  broadcast=broadcast_ip)
 
         with self.ip.routes.tables['mpls'][label] as r:
@@ -362,10 +355,10 @@ class MPLSLinuxDataplaneDriver(dp_drivers.DataplaneDriver):
     def __init__(self):
         super(MPLSLinuxDataplaneDriver, self).__init__()
 
-        self._run_command("modprobe mpls_router")
-        self._run_command("modprobe mpls_gso")
-        self._run_command("modprobe mpls_iptunnel")
-        self._run_command("modprobe vrf")
+        privileged_utils.modprobe('mpls_router')
+        privileged_utils.modprobe('mpls_gso')
+        privileged_utils.modprobe('mpls_iptunnel')
+        privileged_utils.modprobe('vrf')
 
         self.ip = pyroute2.IPDB()  # pylint: disable=no-member
 
